@@ -56,6 +56,10 @@ $example->Label('Border');
 $example->Border(color=>'gold');
 push(@$images,$example);
 $example=$model->Clone();
+$example->Label('Channel');
+$example->Channel();
+push(@$images,$example);
+$example=$model->Clone();
 $example->Label('Charcoal');
 $example->Charcoal();
 push(@$images,$example);
