@@ -14,11 +14,11 @@ $image->Read('xc:white');
 #
 $tile=Image::Magick->new;
 $tile->Read('tile.gif');
-$image->Draw(primitive=>'Polygon',tile=>$tile,
+$image->Draw(primitive=>'Polygon',tile=>$tile,fill=>'none',
   points=>'30,30 100,10 190,290 30,290');
 $image->Draw(stroke=>'red',primitive=>'Ellipse',stroke=>'black',fill=>'red',
-  linewidth=>5,points=>'100,100 50,75 0,360');
-$image->Draw(primitive=>'Polygon',stroke=>'black',linewidth=>5,
+  stroke_width=>5,points=>'100,100 50,75 0,360');
+$image->Draw(primitive=>'Polygon',fill=>'none',stroke=>'black',stroke_width=>5,
   points=>'30,30 100,10 190,290 30,290');
 $image->Set(fuzz=>80);
 $image->ColorFloodfill(geometry=>'+132+62',fill=>'blue');
